unit ModflowIdentifiersUnit;

interface

uses
  SysUtils, Classes, ErrorMessages;

var
  PackageIdentifiers: TAnsiStringList;
  ObsIdentifiers: TAnsiStringList;
  BoundaryIdentifiers: TAnsiStringList;
  NumberBoundaryIdentifiers: TAnsiStringList;
//  KeyWords: TAnsiStringList;
  NonIdentifiers: TAnsiStringList;
//  ShortBoundaryIdentifiers: TAnsiStringList;

const
  StressPeriodID1 = 'STRESS PERIOD NO. ';
  StressPeriodID2 = 'LENGTH =';
  TransportStep = 'TRANSPORT STEP NO.';
  StartNewTimeStep = 'SOLVING FOR HEAD';
  IterationID1 = 'ITERATIONS FOR TIME STEP';
  IterationID2 = 'IN STRESS PERIOD';
  ArrayID1 = ' IN LAYER ';
  ArrayID2 = ' AT END OF TIME STEP ';
  ArrayID3 = ' FOR CROSS SECTION AT END OF TIME STEP';
  ArrayID4 = ' AT END OF TRANSPORT STEP '; // SEAWAT

  BudgetID = 'VOLUMETRIC BUDGET';
  SwiBudgetID = 'VOLUMETRIC SWI ZONE BUDGET';
  SwrBudgetID = 'VOLUMETRIC SURFACE WATER BUDGET';
  SwrBudgetDiscrepancy = 'DISCREPANCY BETWEEN MODFLOW AND SWR1 AQUIFER-REACH';
  TimeSummary = 'TIME SUMMARY';
  EndModel = 'Run end date and time';
  StrParameterName = 'PARAMETER NAME:';
  StrINSTANCE = 'INSTANCE:';
  StrParameter = 'Parameter:';
  StrINSTANCE2 = 'Instance:';
  StrCLASSIFICATIONCOU = 'CLASSIFICATION & COUNT OF STREAM SEGMENTS';
  StrRECHARGE = 'RECHARGE =';

const
  StrHEADANDDRAWDOWNOB = 'HEAD AND DRAWDOWN OBSERVATIONS';
  StrMODELTIMEUNIT = 'MODEL TIME UNIT';
  StrGROUNDSURFACE = 'GROUND SURFACE';


implementation

resourcestring
  StrREUSING = 'REUSING ';

Procedure InitializePackageIdentifiers;
begin
  PackageIdentifiers := TAnsiStringList.Create;
  PackageIdentifiers.Add('BAS -- BASIC PACKAGE');
  PackageIdentifiers.Add('BAS6 -- BASIC PACKAGE, VERSION');
  PackageIdentifiers.Add('BCF -- BLOCK-CENTERED FLOW PACKAGE');
  PackageIdentifiers.Add('BCF6 -- BLOCK-CENTERED FLOW PACKAGE');
  PackageIdentifiers.Add('CHD -- TIME-VARIANT SPECIFIED-HEAD OPTION');
  PackageIdentifiers.Add('CHD6 -- TIME-VARIANT SPECIFIED-HEAD PACKAGE');  // SEAWAT
  PackageIdentifiers.Add('DE4 -- D4 DIRECT SOLUTION PACKAGE');
  PackageIdentifiers.Add('DRN -- DRAIN PACKAGE');
  PackageIdentifiers.Add('DRT7 -- DRAIN RETURN PACKAGE');
  PackageIdentifiers.Add('ETS7 -- EVAPOTRANSPIRATION SEGMENTS PACKAGE');
  PackageIdentifiers.Add('EVT -- EVAPOTRANSPIRATION PACKAGE');
  PackageIdentifiers.Add('FHB1 -- SPECIFIED FLOW PACKAGE');
  PackageIdentifiers.Add('GAGING STATION');
  PackageIdentifiers.Add('GHB -- GENERAL-HEAD BOUNDARY PACKAGE');
  PackageIdentifiers.Add('GMG -- PCG GEOMETRIC MULTI-GRID SOLUTION PACKAGE');
  PackageIdentifiers.Add('HFB -- HORIZONTAL-FLOW BARRIER PACKAGE');
  PackageIdentifiers.Add('HUF2 -- HYDROGEOLOGIC-UNIT FLOW PACKAGE');
  PackageIdentifiers.Add('HYD -- HYDROGRAPH DATA');
  PackageIdentifiers.Add('IBS -- INTERBED STORAGE PACKAGE');
  PackageIdentifiers.Add('LAK7 -- LAKE PACKAGE');
  PackageIdentifiers.Add('LPF -- LAYER-PROPERTY FLOW PACKAGE');
  PackageIdentifiers.Add('MNW1 -- MULTI-NODE WELL 1 PACKAGE');
  PackageIdentifiers.Add('MNW2 -- MULTI-NODE WELL 2 PACKAGE');
  PackageIdentifiers.Add('MNWI Package input');
  PackageIdentifiers.Add('OBS2BAS7 -- HEAD OBSERVATIONS');
  PackageIdentifiers.Add('OBS2CHD7 -- CONSTANT-HEAD BOUNDARY FLOW OBSERVATIONS');
  PackageIdentifiers.Add('OBS2DRN7 -- OBSERVATION PROCESS (DRAIN FLOW OBSERVATIONS)');
  PackageIdentifiers.Add('OBS2GHB7 -- OBSERVATION PROCESS (GHB FLOW OBSERVATIONS)');
  PackageIdentifiers.Add('OBS2RIV7 -- OBSERVATION PROCESS (RIVER FLOW OBSERVATIONS)');
  PackageIdentifiers.Add('OBS2STR7 -- OBSERVATION PROCESS (STREAMFLOW OBSERVATIONS)');
  PackageIdentifiers.Add('PCG -- CONJUGATE-GRADIENT SOLUTION PACKAGE');
  PackageIdentifiers.Add('PCG2 -- CONJUGATE GRADIENT SOLUTION PACKAGE'); // SEAWAT
  PackageIdentifiers.Add('RCH -- RECHARGE PACKAGE');
  PackageIdentifiers.Add('RES7 -- RESERVOIR PACKAGE');
  PackageIdentifiers.Add('RIV -- RIVER PACKAGE');
  PackageIdentifiers.Add('SFR7 -- STREAMFLOW ROUTING PACKAGE');
  PackageIdentifiers.Add('SIP -- STRONGLY-IMPLICIT PROCEDURE SOLUTION PACKAGE');
  PackageIdentifiers.Add('STR -- STREAM PACKAGE');
  PackageIdentifiers.Add('SUB7 -- SUBSIDENCE PACKAGE');
  PackageIdentifiers.Add('SWT -- SUBSIDENCE FOR WATER-TABLE PACKAGE');
  PackageIdentifiers.Add('UZF1 -- UNSATURATED FLOW PACKAGE');
  PackageIdentifiers.Add('WEL -- WELL PACKAGE');
  PackageIdentifiers.Add('MODFLOW-LGR');
  PackageIdentifiers.Add('MODFLOW-NWT');
  PackageIdentifiers.Add('MODFLOW-2005');
  PackageIdentifiers.Add('FMP2 -- FARM PROCESS');
  PackageIdentifiers.Add('SWI2 -- SWI PACKAGE');
  PackageIdentifiers.Add('SWR -- SURFACE-WATER ROUTING PACKAGE');
  PackageIdentifiers.Add('NWT1 -- Newton Solver');
  PackageIdentifiers.Add('UPW1 -- UPSTREAM WEIGHTING FLOW PACKAGE');


//  PackageIdentifiers.Add(StrCLASSIFICATIONCOU);
end;


Procedure InitializeObsIdentifiers;
begin
  ObsIdentifiers:= TAnsiStringList.Create;
  ObsIdentifiers.Add(StrHEADANDDRAWDOWNOB);
  ObsIdentifiers.Add('CONSTANT HEAD FLOW OBSERVATIONS');
  ObsIdentifiers.Add('DRAIN FLOW OBSERVATIONS');
  ObsIdentifiers.Add('GHB FLOW OBSERVATIONS');
  ObsIdentifiers.Add('RIVER FLOW OBSERVATIONS');
  ObsIdentifiers.Add('STREAMFLOW OBSERVATIONS');
end;

procedure InitializeBoundaryIdentifiers;
begin
  NumberBoundaryIdentifiers := TAnsiStringList.Create;
  NumberBoundaryIdentifiers.Add('parameters');

  BoundaryIdentifiers := TAnsiStringList.Create;
  BoundaryIdentifiers.Add(AnsiString(StrREUSING));
  BoundaryIdentifiers.Add('WELL NO.  LAYER   ROW   COL   STRESS RATE');
  BoundaryIdentifiers.Add('DRAIN NO.  LAYER   ROW   COL     DRAIN EL.  CONDUCTANCE');
  BoundaryIdentifiers.Add('REACH NO.  LAYER   ROW   COL');
  BoundaryIdentifiers.Add('EVTR array defined by the following parameters:');
  BoundaryIdentifiers.Add('MULT. ARRAY:');
//  BoundaryIdentifiers.Add(' MULT. ARRAY:');
//  BoundaryIdentifiers.Add(' HK ');
//  BoundaryIdentifiers.Add(' HANI ');
//  BoundaryIdentifiers.Add(' SS ');
//  BoundaryIdentifiers.Add(' SY ');
//  BoundaryIdentifiers.Add(' ETS ');
//  BoundaryIdentifiers.Add(' EVT ');
//  BoundaryIdentifiers.Add(' RCH ');
  BoundaryIdentifiers.Add('BOUND. NO. LAYER   ROW   COL     STAGE      CONDUCTANCE');
  BoundaryIdentifiers.Add('LAYER   ROW    COL    SEGMENT   REACH');
  BoundaryIdentifiers.Add('TABULAR INFLOWS WERE READ');
  BoundaryIdentifiers.Add('OUTPUT CONTROL FOR STRESS PERIOD');
  BoundaryIdentifiers.Add('CHD NO.   LAYER   ROW   COL    START HEAD        END HEAD');
  BoundaryIdentifiers.Add('STREAM NETWORK DESCRIPTION');
  BoundaryIdentifiers.Add('USING INFILTRATION RATE FROM PREVIOUS STRESS ');
  BoundaryIdentifiers.Add('USING ET RATE FROM PREVIOUS STRESS');
  BoundaryIdentifiers.Add('USING ET EXTINCTION DEPTH FROM PREVIOUS');
  BoundaryIdentifiers.Add('USING EXTINCTION WATER CONTENT FROM PREVIOUS');
  BoundaryIdentifiers.Add('INITIAL LAKE STAGE:  LAKE    STAGE    SS MIN    SS MAX');
  BoundaryIdentifiers.Add('INITIAL LAKE CONCENTRATIONS:  LAKE   CONCENTRATION');
  BoundaryIdentifiers.Add('EVAPOTRANS. RATE (ETSR)');
  BoundaryIdentifiers.Add('EXTINCT. DEP. PROPORTION');
  BoundaryIdentifiers.Add('ET RATE PROPORTION');
  BoundaryIdentifiers.Add('ET LAYER INDEX');
  BoundaryIdentifiers.Add('ET SURFACE');
  BoundaryIdentifiers.Add('EVAPOTRANSPIRATION RATE');
  BoundaryIdentifiers.Add('EXTINCTION DEPTH');
  BoundaryIdentifiers.Add('RECHARGE LAYER INDEX');
  BoundaryIdentifiers.Add('RECHARGE');
  BoundaryIdentifiers.Add('DRAIN NO.  LAYER   ROW   COL     DRAIN EL.  STRESS FACTOR');
  BoundaryIdentifiers.Add('DRAIN NO.  LAYER   ROW   COL   LAYER   ROW   COL    PROP.');
  BoundaryIdentifiers.Add('DRAIN NO.  LAYER   ROW   COL     DRAIN EL.  CONDUCTANCE');
//  BoundaryIdentifiers.Add('WELLID             NNODES    LOSSTYPE');
  BoundaryIdentifiers.Add('    No.   Lay   Row   Col    Stress   QW param');
  BoundaryIdentifiers.Add('TOP ELEVATN');
  BoundaryIdentifiers.Add('THICKNESS');
  BoundaryIdentifiers.Add('PARAMETER NAME');
  BoundaryIdentifiers.Add('INTERPRETATION OF UNIT FLAGS:');
  BoundaryIdentifiers.Add('HYD. COND. ALONG ROWS');
  BoundaryIdentifiers.Add('HORIZ. ANI. (COL./ROW)');
  BoundaryIdentifiers.Add('VERTICAL HYD. COND.');
  BoundaryIdentifiers.Add('TOP ELEVATION OF LAYER');
  BoundaryIdentifiers.Add('TOP ELEV. OF');
  BoundaryIdentifiers.Add('MODEL LAYER BOTTOM EL.');
  BoundaryIdentifiers.Add('STRESS PERIOD     LENGTH       TIME STEPS     MULTIPLIER FOR DELT    SS FLAG');
  BoundaryIdentifiers.Add('BOUNDARY ARRAY');
  BoundaryIdentifiers.Add('INITIAL HEAD');
  BoundaryIdentifiers.Add('LAYER FLAGS:');
  BoundaryIdentifiers.Add('SPECIFIC YIELD');
  BoundaryIdentifiers.Add('LAYER    ROW    COL   SEGMENT   REACH     LENGTH');
  BoundaryIdentifiers.Add('AREAL EXTENT OF UZ FLOW');
  BoundaryIdentifiers.Add('ROUTING OVERLAND RUNOFF');
  BoundaryIdentifiers.Add('SATURATED VERTICAL K');
  BoundaryIdentifiers.Add('BROOKS-COREY EPSILON');
  BoundaryIdentifiers.Add('SATURATED WATER CONTENT');
  BoundaryIdentifiers.Add('SELECTED MODEL CELLS ARE:');
  BoundaryIdentifiers.Add('SEGMENT    SEG.     INFLOW   OVERLAND   STREAM');
  BoundaryIdentifiers.Add('SEGMENT     BED HYD. COND.      BED THICKNESS');
  BoundaryIdentifiers.Add('EIGHT POINT CROSS-SECTION DATA');
  BoundaryIdentifiers.Add('STREAMFLOW RELATION WITH DEPTH IS BASED ON EQUATION');
  BoundaryIdentifiers.Add('STREAMFLOW RELATION WITH DEPTH AND WIDTH IS BASED');
  BoundaryIdentifiers.Add('AREAL INFILTRATION RATE');
  BoundaryIdentifiers.Add('ET RATE');
  BoundaryIdentifiers.Add('ET EXTINCTION DEPTH');
  BoundaryIdentifiers.Add('EXTINCTION WATER CONTENT');
  BoundaryIdentifiers.Add('MAXIMUM HEAD CHANGE FOR EACH ITERATION');
  BoundaryIdentifiers.Add('WELLS   PERIOD');
  BoundaryIdentifiers.Add('HEAD DEP BOUNDS   PERIOD');
  BoundaryIdentifiers.Add('UNSATURATED ZONE PACKAGE VOLUMETRIC BUDGET');
  BoundaryIdentifiers.Add('STREAM LISTING     PERIOD');
  BoundaryIdentifiers.Add('AT ALL NO-FLOW NODES');
  BoundaryIdentifiers.Add('ZONE ARRAY:');
  BoundaryIdentifiers.Add('INTERPRETATION OF LAYER FLAGS:');
  BoundaryIdentifiers.Add('QUASI3D VERT. HYD. COND.');
  BoundaryIdentifiers.Add('HEAD IN LAYER');
  BoundaryIdentifiers.Add('HEAD AT CELLS THAT CONVERT TO DRY');
  BoundaryIdentifiers.Add('VERT HYD COND /THICKNESS');
  BoundaryIdentifiers.Add('TRANSMIS. ALONG ROWS');
  BoundaryIdentifiers.Add('BARRIER  LAYER  IROW1  ICOL1  IROW2  ICOL2    HYDCHR');
  BoundaryIdentifiers.Add('COLUMN TO ROW ANISOTROPY');
  BoundaryIdentifiers.Add('LAYER  LAYER-TYPE CODE     INTERBLOCK T');
  BoundaryIdentifiers.Add('PRIMARY STORAGE COEF');
  BoundaryIdentifiers.Add('MODEL LAYER ASSIGNMENTS');
  BoundaryIdentifiers.Add('OF DELAY BEDS:');
  BoundaryIdentifiers.Add('OF NO-DELAY BEDS:');
  BoundaryIdentifiers.Add('PRECONSOLIDATION HEAD');
  BoundaryIdentifiers.Add('ELASTIC INTERBED STORAGE');
  BoundaryIdentifiers.Add('VIRGIN INTERBED STORAGE');
  BoundaryIdentifiers.Add('STARTING COMPACTION');
  BoundaryIdentifiers.Add('MATERIAL PROPERTIES OF INTERBEDS');
  BoundaryIdentifiers.Add('DELAY STARTING HEAD');
  BoundaryIdentifiers.Add('DELAY PRECOLSOL. HEAD');
  BoundaryIdentifiers.Add('DELAY INITIAL COMPACTION');
  BoundaryIdentifiers.Add('DELAY INTERBED THICKNESS');
  BoundaryIdentifiers.Add('MATERIAL ZONE INDICES');
  BoundaryIdentifiers.Add('VOLUMETRIC BUDGET FOR SYSTEMS OF DELAY INTERBEDS');
  BoundaryIdentifiers.Add('VOLUMETRIC BUDGET FOR UNSATURATED ZONE');
  BoundaryIdentifiers.Add('DELC');
  BoundaryIdentifiers.Add('DELR');
  BoundaryIdentifiers.Add('STREAMBED PROPERTIES');
  BoundaryIdentifiers.Add('HEAD AT END OF TIME STEP');
  BoundaryIdentifiers.Add(StrMODELTIMEUNIT);
  BoundaryIdentifiers.Add('MODEL LENGTH UNIT');
  BoundaryIdentifiers.Add('MODEL LAYER ASSIGNMENTS');
  BoundaryIdentifiers.Add('GEOSTATIC STRESS');
  BoundaryIdentifiers.Add('MOIST SPECIFIC GRAVITY');
  BoundaryIdentifiers.Add('SAT. SPECIFIC GRAVITY');
  BoundaryIdentifiers.Add('SILT AND CLAY THICKNESS');
  BoundaryIdentifiers.Add('RECOMPRESSION INDEX');
  BoundaryIdentifiers.Add('COMPRESSION INDEX');
  BoundaryIdentifiers.Add('VOID RATIO');
  BoundaryIdentifiers.Add('STARTING COMPACTION');
  BoundaryIdentifiers.Add('PRECONSOL.   STRESS');
  BoundaryIdentifiers.Add('GEOSTATIC STRESS');
  BoundaryIdentifiers.Add('EFFECTIVE STRESS');
  BoundaryIdentifiers.Add('PRECONSOL STRESS');
  BoundaryIdentifiers.Add('EQUIVALENT Sske');
  BoundaryIdentifiers.Add('EQUIVALENT Sskv');
  BoundaryIdentifiers.Add('SUBSIDENCE IN LAYER');
  BoundaryIdentifiers.Add('LAYER COMPACTION IN LAYER');
  BoundaryIdentifiers.Add('CHANGE IN PCSTRS IN LAYER');
  BoundaryIdentifiers.Add('CHANGE IN G-STRS IN LAYER');
  BoundaryIdentifiers.Add('CHANGE IN EFF-ST IN LAYER');
  BoundaryIdentifiers.Add('STREAM SEGMENT               TRIBUTARY STREAM SEGMENT');
  BoundaryIdentifiers.Add('DIVERSION SEGMENT NUMBER          UPSTREAM SEGMENT NUMBER');
  BoundaryIdentifiers.Add('LAYER      ROW     COLUMN     STREAM');
  BoundaryIdentifiers.Add('SECONDARY STORAGE COEF');
  BoundaryIdentifiers.Add('WETDRY PARAMETER');
  BoundaryIdentifiers.Add('RESERVOIR LOCATION');
  BoundaryIdentifiers.Add('RESERVOIR LAND SURF ELEV');
  BoundaryIdentifiers.Add('RES. BED VERT HYD COND');
  BoundaryIdentifiers.Add('RESERVOIR BED THICKNESS');
  BoundaryIdentifiers.Add('STAGE-VOLUME TABLE FOR RESERVOIR');
  BoundaryIdentifiers.Add('RESERVOIR CONDITIONS FOR STRESS PERIOD');
  BoundaryIdentifiers.Add('MNW2 Well Conductance and Screen');
  BoundaryIdentifiers.Add('Entry LAY ROW COL         Q');
  BoundaryIdentifiers.Add('Multi-Node Rates & Average QW');
  BoundaryIdentifiers.Add('LAYER  ROW  COL IAUX');
  BoundaryIdentifiers.Add('LAKE ID ARRAY');
  BoundaryIdentifiers.Add('LAKEBED LEAKANCE ARRAY');
  BoundaryIdentifiers.Add('LOCATIONS, LAKE #');
  BoundaryIdentifiers.Add('STAGE/VOLUME RELATION');
  BoundaryIdentifiers.Add('NUMBER OF CONNECTED');
  BoundaryIdentifiers.Add('LAKE       PRECIP     EVAP');
  BoundaryIdentifiers.Add('INTERFACE CONDUCTANCES BETWEEN LAKE AND AQUIFER CELLS');
  BoundaryIdentifiers.Add('HYDROLOGIC BUDGET SUMMARIES');
  BoundaryIdentifiers.Add('CUMULATIVE HYDROLOGIC BUDGET SUMMARIES');
  BoundaryIdentifiers.Add('TIMES FOR SPECIFYING FLOWS AND HEADS');
  BoundaryIdentifiers.Add('INFORMATION ON PARAMETERS LISTED IN PARAMETER FILE');
  BoundaryIdentifiers.Add('MAXIMUM RESIDUAL FOR EACH ITERATION');
  BoundaryIdentifiers.Add('BOT. EL. OF QUASI-3D BED');
  BoundaryIdentifiers.Add('HORIZ. TO VERTICAL ANI.');
  BoundaryIdentifiers.Add('SPECIFIC STORAGE');
  BoundaryIdentifiers.Add('STORAGE COEFFICIENT');
  BoundaryIdentifiers.Add('RESERVOIR LAYER INDEX');
  BoundaryIdentifiers.Add('ELASTIC SPECIFIC STORAGE');
  BoundaryIdentifiers.Add('INELAS. SPECIFIC STORAGE');
  BoundaryIdentifiers.Add('ELEV. OF LAYER CENTER');
  BoundaryIdentifiers.Add('ELEV. OF LAND SURFACE');
  BoundaryIdentifiers.Add('CENTER ELEVATION');
  BoundaryIdentifiers.Add('EQUIVALENT Cr');
  BoundaryIdentifiers.Add('EQUIVALENT Cc');
  BoundaryIdentifiers.Add('INITIAL WATER CONTENT');
  BoundaryIdentifiers.Add('UZ CELL BOTTOM ELEV.');
//  BoundaryIdentifiers.Add(StrINSTANCE);
  BoundaryIdentifiers.Add('VOLUMETRIC BUDGET FOR ENTIRE MODEL');
  BoundaryIdentifiers.Add('INPUT DATA FOR EACH STREAM SEGMENT');
  BoundaryIdentifiers.Add('Stream Gages:');
  BoundaryIdentifiers.Add('Lake Gages:');
  BoundaryIdentifiers.Add('OPTION HAS BEEN SELECTED');
  BoundaryIdentifiers.Add('When solver convergence criteria are not met');
  BoundaryIdentifiers.Add('CROSS SECTION OPTION IS SPECIFIED');
  BoundaryIdentifiers.Add('CALCULATE FLOW BETWEEN ADJACENT CONSTANT-HEAD CELLS');
  BoundaryIdentifiers.Add('OUTPUT CONTROL');
  BoundaryIdentifiers.Add('WETTING CAPABILITY');
  BoundaryIdentifiers.Add('PARAMETERS DEFINED');
  BoundaryIdentifiers.Add('Parameters');
  BoundaryIdentifiers.Add('PRINTCODE FLAGS');
  BoundaryIdentifiers.Add('MNW2:');
  BoundaryIdentifiers.Add('MNW2 Input:');

  // MODFLOW-2000
  BoundaryIdentifiers.Add('INTERPRETING THE CALCULATED RUNS STATISTIC VALUE');

  // SEAWAT
  BoundaryIdentifiers.Add('MASS BUDGET FOR ENTIRE MODEL');
  BoundaryIdentifiers.Add('SEAWAT');
  BoundaryIdentifiers.Add('THE TRANSPORT MODEL CONSISTS OF');
  BoundaryIdentifiers.Add('POROSITY                 FOR LAYER');
  BoundaryIdentifiers.Add('INITIAL CONC.: COMP');
  BoundaryIdentifiers.Add('OUTPUT CONTROL OPTIONS');
  BoundaryIdentifiers.Add('ADVECTION SOLUTION OPTIONS');
  BoundaryIdentifiers.Add('DISPERSION INPUT PARAMETERS');
  BoundaryIdentifiers.Add('LONG. DISPERSIVITY (AL)  FOR LAYER');
  BoundaryIdentifiers.Add('SOLUTION BY THE GENERALIZED CONJUGATE GRADIENT METHOD');
  BoundaryIdentifiers.Add('NO    LAYER   ROW   COLUMN   CONCENTRATION       TYPE');

  // FMP2
  BoundaryIdentifiers.Add('WHEN TO READ SETTINGS:');
  BoundaryIdentifiers.Add('WATER POLICY SETTINGS:');
  BoundaryIdentifiers.Add('CONSUMPTIVE USE CONCEPT');
  BoundaryIdentifiers.Add('SURFACE-WATER SETTINGS (SUPPLY / RETURNFLOW / RIGHTS:');
  BoundaryIdentifiers.Add('PRINT SETTINGS:');
  BoundaryIdentifiers.Add('AUXILIARY FARM WELL PARAMETER:');
  BoundaryIdentifiers.Add('WELL NO. LAYER    ROW    COL  F-WELL ID    FARM ID      QMAXfac');
  BoundaryIdentifiers.Add(StrGROUNDSURFACE);
  BoundaryIdentifiers.Add('FARM IDENTIFICATION');
  BoundaryIdentifiers.Add('SOIL TYPE IDENTIFICATION');
  BoundaryIdentifiers.Add('NUMBER OF ACTIVE FARM WELLS:');
  BoundaryIdentifiers.Add('FARM-ID  NUMBER OF WELLS PER FARM  TOTAL MAX.CAPACITY PER FARM');
  BoundaryIdentifiers.Add('CROP IDENTIFICATION');
  BoundaryIdentifiers.Add('REF. EVAPOTRANSPIRATION');
  BoundaryIdentifiers.Add('Transpiratory and Evaporative Fractions of Crop Consumptive Use');
  BoundaryIdentifiers.Add('FRACTIONS OF IN-EFFICIENT LOSSES TO SW-RUNOFF FROM');
  BoundaryIdentifiers.Add('SEMI-ROUTED DELIVERIES TO FARMS (LOCATION OF DIVERSION-POINTS):');
  BoundaryIdentifiers.Add('SEMI-ROUTED RUNOFF-RETURNFLOW FROM FARMS (LOCATION WHERE RUNOFF ENTERS A STREAM REACH):');
  BoundaryIdentifiers.Add('FARM ALLOTMENT HEIGHT [L]:');
  BoundaryIdentifiers.Add('WELL NO. LAYER    ROW    COL  F-WELL ID    FARM ID      QMAX');
  BoundaryIdentifiers.Add('UNRANKED LIST OF NON-ROUTED DELIVERIES TO FARMS [L3]:');
  BoundaryIdentifiers.Add('LIST OF NON-ROUTED DELIVERIES IN RANKED SEQUENCE [L3/T]:');
  BoundaryIdentifiers.Add('FULLY ROUTED DELIVERY FROM THE FIRST, MOST');
  BoundaryIdentifiers.Add('FULLY ROUTED RUNOFF-RETURNFLOW PRORATED');
  BoundaryIdentifiers.Add('SEMI-ROUTED RUNOFF-RETURNFLOW');
  BoundaryIdentifiers.Add('FRACTIONS OF ACTIVE CELL ACREAGE');
  BoundaryIdentifiers.Add('ACREAGE OPTIMIZATION - TABLEAU MATRIX:');
  BoundaryIdentifiers.Add('PRIOR APPROPRIATION FOR FARM:');
  BoundaryIdentifiers.Add('ROUTING INFORMATION FOR FARM:');
  BoundaryIdentifiers.Add('DELIVERIES:');
  BoundaryIdentifiers.Add('SEMI-ROUTED DELIVERIES:');
  BoundaryIdentifiers.Add('RETURNFLOWS:');
  BoundaryIdentifiers.Add('FRACTIONS OF OPTIMIZED CELL AREAS:');
  BoundaryIdentifiers.Add('PRECIPITATION FLUX');

  // SWI
  BoundaryIdentifiers.Add('SWI2 DATASET');
  BoundaryIdentifiers.Add('NUZONE');
  BoundaryIdentifiers.Add('ZETA SURFACE');
  BoundaryIdentifiers.Add('SSZ');
  BoundaryIdentifiers.Add('IZONENR');

  // SWR
  BoundaryIdentifiers.Add('READING SWR1 PROCESS DATASET');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
//  BoundaryIdentifiers.Add('aaa');
end;

procedure InitializeNonIdenfiers;
begin
  NonIdentifiers := TAnsiStringList.Create;
//  NonIdentifiers.Add(StrRECHARGE);
  NonIdentifiers.Add('RECHARGE"');
  NonIdentifiers.Add('BUDGET ERROR:');
  NonIdentifiers.Add('MULTIPLIER ARRAY:');
  NonIdentifiers.Add('RECHARGE TO GW =');
  NonIdentifiers.Add('THETA');
  // FMP
  NonIdentifiers.Add('NET RECHARGE');
  NonIdentifiers.Add('VOLUMETRIC BUDGET ERROR:');
  NonIdentifiers.Add('PRECIPITATION FLUX ...');
  // CFP
  NonIdentifiers.Add('NO WARNINGS');
end;

//procedure InitializeShortBoundaryIdentifiers;
//begin
//  ShortBoundaryIdentifiers := TAnsiStringList.Create;
//  ShortBoundaryIdentifiers.Add('LAYER');
//  ShortBoundaryIdentifiers.Add(':');
//  ShortBoundaryIdentifiers.Add(' HK ');
//  ShortBoundaryIdentifiers.Add(' HANI ');
//  ShortBoundaryIdentifiers.Add(' SS ');
//  ShortBoundaryIdentifiers.Add(' SY ');
//  ShortBoundaryIdentifiers.Add(' ETS ');
//  ShortBoundaryIdentifiers.Add(' EVT ');
//  ShortBoundaryIdentifiers.Add(' RCH ');
//  ShortBoundaryIdentifiers.Add('STREAM');
//  ShortBoundaryIdentifiers.Add('USING');
//  ShortBoundaryIdentifiers.Add('LAKE');
//  ShortBoundaryIdentifiers.Add('RATE');
//  ShortBoundaryIdentifiers.Add('PROPORTION');
//  ShortBoundaryIdentifiers.Add('ET');
//  ShortBoundaryIdentifiers.Add('EXTINCT');
//  ShortBoundaryIdentifiers.Add('RECHARGE');
//  ShortBoundaryIdentifiers.Add('WELLID');
//  ShortBoundaryIdentifiers.Add('Lay');
//  ShortBoundaryIdentifiers.Add('TOP');
//  ShortBoundaryIdentifiers.Add('THICKNESS');
//  ShortBoundaryIdentifiers.Add('PARAMETER');
//  ShortBoundaryIdentifiers.Add('OF');
//  ShortBoundaryIdentifiers.Add('ROW');
//  ShortBoundaryIdentifiers.Add('HYD');
//  ShortBoundaryIdentifiers.Add('PERIOD');
//  ShortBoundaryIdentifiers.Add('ARRAY');
//  ShortBoundaryIdentifiers.Add('HEAD');
//  ShortBoundaryIdentifiers.Add('SPECIFIC');
//  ShortBoundaryIdentifiers.Add('OVERLAND');
//  ShortBoundaryIdentifiers.Add('SATURATED');
//  ShortBoundaryIdentifiers.Add('BROOKS');
//  ShortBoundaryIdentifiers.Add('DATA');
//  ShortBoundaryIdentifiers.Add('BUDGET');
//  ShortBoundaryIdentifiers.Add('AT');
//
//end;

//procedure InitializeKeyWords;
//var
//  Splitter: TStringList;
//  TempKeyWords: TStringList;
//  Storage: TStringList;
//  LineIndex: Integer;
//  MaxWordCount: Integer;
//  WordIndex: Integer;
//  AWord: string;
//  WordCount: Integer;
//  MaxWordIndex: Integer;
//  BadCharIndex: Integer;
//  AValue: Extended;
//  ErrorCode: integer;
//  procedure AddStrings(List: TAnsiStringList);
//  var
//    index: Integer;
//  begin
//    for index := 0 to List.Count - 1 do
//    begin
//      Storage.Add(string(List[index]))
//    end;
//  end;
//begin
//  KeyWords := TAnsiStringList.Create;
//  TempKeyWords := TStringList.Create;
//  Splitter := TStringList.Create;
//  Storage := TStringList.Create;
//  try
//    Storage.Add(StressPeriodID1);
//    Storage.Add(StressPeriodID2);
//    Storage.Add(StartNewTimeStep);
//    Storage.Add(TransportStep);
//    Storage.Add(IterationID1);
//    Storage.Add(IterationID2);
//    Storage.Add(ArrayID1);
//    Storage.Add(ArrayID2);
//    Storage.Add(ArrayID3);
//    Storage.Add(ArrayID4);
//    Storage.Add(BudgetID);
//    Storage.Add(TimeSummary);
//    Storage.Add(EndModel);
//    Storage.Add(StrParameterName);
//    Storage.Add(StrINSTANCE);
//    Storage.Add(StrParameter);
//    Storage.Add(StrINSTANCE2);
//    Storage.Add(StrCLASSIFICATIONCOU);
//
//    AddStrings(PackageIdentifiers);
//    AddStrings(ObsIdentifiers);
//    AddStrings(BoundaryIdentifiers);
//    AddStrings(ErrorValues);
//    AddStrings(NumberErrorValues);
//    AddStrings(WarningValues);
//
//    Splitter.Delimiter := ' ';
//    TempKeyWords.Duplicates := dupIgnore;
//    TempKeyWords.Sorted := True;
//
//    for LineIndex := 0 to Storage.Count - 1 do
//    begin
//      Splitter.DelimitedText := Storage[LineIndex];
//      TempKeyWords.AddStrings(Splitter);
//    end;
//
//    BadCharIndex := TempKeyWords.IndexOf('E');
//    if BadCharIndex >= 0 then
//    begin
//      TempKeyWords.Delete(BadCharIndex);
//    end;
//    BadCharIndex := TempKeyWords.IndexOf('+');
//    if BadCharIndex >= 0 then
//    begin
//      TempKeyWords.Delete(BadCharIndex);
//    end;
//    BadCharIndex := TempKeyWords.IndexOf('-');
//    if BadCharIndex >= 0 then
//    begin
//      TempKeyWords.Delete(BadCharIndex);
//    end;
//    BadCharIndex := TempKeyWords.IndexOf('.');
//    if BadCharIndex >= 0 then
//    begin
//      TempKeyWords.Delete(BadCharIndex);
//    end;
//    for WordIndex := TempKeyWords.Count - 1 downto 0 do
//    begin
////      if Length(TempKeyWords[WordIndex]) = 1 then
////      begin
////        TempKeyWords.Delete(WordIndex);
////      end
////      else
////      begin
//        Val(TempKeyWords[WordIndex], AValue, ErrorCode);
//        if ErrorCode = 0 then
//        begin
//          TempKeyWords.Delete(WordIndex);
//        end;
////      end;
//    end;
//
//    while Storage.Count > 0 do
//    begin
//      MaxWordCount := 0;
//      MaxWordIndex := -1;
//      for WordIndex := 0 to TempKeyWords.Count - 1 do
//      begin
//        AWord := TempKeyWords[WordIndex];
//        WordCount := 0;
//        for LineIndex := 0 to Storage.Count - 1 do
//        begin
//          if Pos(AWord, Storage[LineIndex]) > 0  then
//          begin
//            Inc(WordCount);
//          end;
//        end;
//        if WordCount > MaxWordCount then
//        begin
//          MaxWordCount := WordCount;
//          MaxWordIndex := WordIndex;
//        end;
//      end;
//      Assert(MaxWordIndex >= 0);
//      AWord := TempKeyWords[MaxWordIndex];
//      TempKeyWords.Delete(MaxWordIndex);
//      KeyWords.Add(AnsiString(AWord));
//      for LineIndex := Storage.Count - 1 downto 0 do
//      begin
//        if Pos(AWord, Storage[LineIndex]) > 0  then
//        begin
//          Storage.Delete(LineIndex);
//        end;
//      end;
//    end;
//  finally
//    Storage.Free;
//    TempKeyWords.Free;
//    Splitter.Free;
//  end;
//end;

initialization
  InitializePackageIdentifiers;
  InitializeObsIdentifiers;
  InitializeBoundaryIdentifiers;
  InitializeNonIdenfiers;
//  InitializeShortBoundaryIdentifiers;
//  InitializeKeyWords;

finalization;
  PackageIdentifiers.Free;
  ObsIdentifiers.Free;
  BoundaryIdentifiers.Free;
  NumberBoundaryIdentifiers.Free;
  NonIdentifiers.Free;
//  ShortBoundaryIdentifiers.Free;
//  KeyWords.Free;
end.
